@@ -86,15 +86,15 @@ class Adumo:
             "status": SUCCESS,
             "transaction_id": transaction_id,
             "md": md,
-            "pares": acs_payload,
+            "pareq": acs_payload,
             "acs_url": acs_url,
         }
 
-    def authorise_and_settle_payment(self, pares, md):
+    def authorise_and_settle_payment(self, pareq, md):
         transaction_id, amount, cvv = self.decode_md(md)
 
         try:
-            self._authenticate(pares, md)
+            self._authenticate(pareq, md)
         except CreditCardProcessor3dsFailure():
             return {"status": FAILED, "transaction_id": transaction_id}
 
@@ -104,9 +104,9 @@ class Adumo:
 
         return result
 
-    def _authenticate(self, pares: str, md: str):
+    def _authenticate(self, pareq: str, md: str):
         url = f"{API_URL}product/authentication/v1/tds/authenticate/"
-        request = {"md": md, "payload": pares}
+        request = {"md": md, "payload": pareq}
         result = httpx.post(url, json=request, headers=self.headers)
 
         response_dict = self._process_response(result)
